| Title: | Rank-Based Stability Index (RSI) for Genotype by Environment Studies |
|---|---|
| Description: | Provides functions to compute the Rank-Based Stability Index (RSI) for genotype by environment interaction data, along with a genotype plus genotype-by-environment (GGE) style biplot visualization of stability. |
| Authors: | Prakash Kumar [aut, cre], Himadri Sekhar Roy [aut], Ranjit Kumar Paul [aut], Md. Yeasin [aut], Sunil Kumar Yadav [aut], Amrit Kumar Paul [aut] |
| Maintainer: | Prakash Kumar <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-22 08:01:20 UTC |
| Source: | https://github.com/cran/NPStability |
Compute Rank-based Stability Index (RSI)
compute_rsi(data, y, gen, env, rep = NULL)compute_rsi(data, y, gen, env, rep = NULL)
data |
A data frame with genotype, environment, and response columns. |
y |
Response variable column. |
gen |
Genotype column. |
env |
Environment column. |
rep |
Optional replication column. |
A table containing RSI values for each genotype.
1. Kumar, P., Paul, A. K., Paul, R. K., Raju, B., Rathod, S., Ray, M., ... & Yeasin, M. (2024). A robust non-parametric stability measure to select stable genotypes. *The Indian Journal of Agricultural Sciences*, 94(9), 1007–1012. 2. Pour-Aboughadareh, A., Khalili, M., Poczai, P., & Olivoto, T. (2022). Stability Indices to Deciphering the Genotype-by-Environment Interaction (GEI) Effect: An Applicable Review for Use in Plant Breeding Programs. *Plants*, 11(3), 414.
library(NPStability) library(dplyr) data(example_data) rsi_results <- compute_rsi(example_data, Yield, Gen, Env) rsi_biplot <- rsi_biplot(example_data, Yield, Gen, Env, rsi_table = rsi_results)library(NPStability) library(dplyr) data(example_data) rsi_results <- compute_rsi(example_data, Yield, Gen, Env) rsi_biplot <- rsi_biplot(example_data, Yield, Gen, Env, rsi_table = rsi_results)
A small dataset containing 4 genotypes tested in 2 environments with yield data.
example_dataexample_data
A data frame with 8 rows and 3 variables:
Genotype ID (factor)
Environment (factor)
Yield values (numeric)
Generated for demonstration purposes
Create GGE-style biplot annotated by RSI
rsi_biplot(data, y, gen, env, rsi_table = NULL)rsi_biplot(data, y, gen, env, rsi_table = NULL)
data |
Data frame with genotype, environment, and response columns. |
y |
Response variable column. |
gen |
Genotype column. |
env |
Environment column. |
rsi_table |
Optional RSI table from compute_rsi(). |
A ggplot object of the biplot.
library(NPStability) data(example_data) rsi_results <- compute_rsi(example_data, Yield, Gen, Env) rsi_biplot(example_data, Yield, Gen, Env, rsi_table = rsi_results)library(NPStability) data(example_data) rsi_results <- compute_rsi(example_data, Yield, Gen, Env) rsi_biplot(example_data, Yield, Gen, Env, rsi_table = rsi_results)